==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceDataProviderSchemaChangedEventArgsDescription } from "./DataSourceDataProviderSchemaChangedEventArgsDescription";
/**
 * @hidden
 */
export let DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a == null) {
                DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.c(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.b(a);
            a.ad("DataSourceDataProviderSchemaChangedEventArgs", () => new DataSourceDataProviderSchemaChangedEventArgsDescription());
            a.ac("DataSourceDataProviderSchemaChangedEventArgs", DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
        }
    }
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata, 'DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata');
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceDataProviderSchemaChangedEventArgsDescription } from "./DataSourceDataProviderSchemaChangedEventArgsDescription";
/**
 * @hidden
 */
export let DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a == null) {
                DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.c(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.b(a);
            a.ae("DataSourceDataProviderSchemaChangedEventArgs", () => new DataSourceDataProviderSchemaChangedEventArgsDescription());
            a.ad("DataSourceDataProviderSchemaChangedEventArgs", DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
        }
    }
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata, 'DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata');
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata;
})();
